package com.ruoyi.web.controller.quot;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.MinioUtil;
import com.ruoyi.common.utils.uuid.UUID;
import com.ruoyi.customer.domain.Customer;
import com.ruoyi.quot.domain.QuotFile;
import com.ruoyi.quot.service.IQuotFileService;
import com.ruoyi.web.utils.IdUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.quot.domain.Quot;
import com.ruoyi.quot.service.IQuotService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 报价Controller
 *
 * @author ruoyi
 * @date 2024-04-01
 */
@RestController
@RequestMapping("/quot/quot")
public class QuotController extends BaseController
{
    @Autowired
    private IQuotService quotService;

    @Autowired
    private IQuotFileService quotFileService;

    /**
     * 查询报价列表
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:list')")
    @GetMapping("/list")
    public TableDataInfo list(Quot quot)
    {
        startPage();
        List<Quot> list = quotService.selectQuotList(quot);
        return getDataTable(list);
    }

    /**
     * 导出报价列表
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:export')")
    @Log(title = "报价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Quot quot)
    {
        List<Quot> list = quotService.selectQuotList(quot);
        ExcelUtil<Quot> util = new ExcelUtil<Quot>(Quot.class);
        util.exportExcel(response, list, "报价数据");
    }

    /**
     * 获取报价详细信息
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:query')")
    @GetMapping(value = "/{quotId}")
    public AjaxResult getInfo(@PathVariable("quotId") String quotId)
    {
        return success(quotService.selectQuotByQuotId(quotId));
    }

    /**
     * 新增报价
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:add')")
    @Log(title = "报价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Quot quot)
    {
        quot.setQuotId(UUID.fastUUID().toString());
        quot.setQuotCode(IdUtils.createNo("BJD_",2));
        quot.setCreateBy(getUsername());

        String quotJsxzGroup = quot.getQuotJsxzGroup();
        System.out.println(quotJsxzGroup);
        return toAjax(quotService.insertQuot(quot));
    }

    /**
     * 修改报价
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:edit')")
    @Log(title = "报价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Quot quot)
    {
        quot.setUpdateBy(getUsername());
        return toAjax(quotService.updateQuot(quot));
    }

    /**
     * 删除报价
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:remove')")
    @Log(title = "报价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{quotIds}")
    public AjaxResult remove(@PathVariable String[] quotIds)
    {
        return toAjax(quotService.deleteQuotByQuotIds(quotIds));
    }

    /**
     * 头像上传SysNoticeMapper
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:list')")
    @Log(title = "上传报价附件", businessType = BusinessType.INSERT)
    @PostMapping("/quotFile")
    public AjaxResult quotFile(@RequestParam("quotFile") MultipartFile file,@RequestParam("relation_id") String relation_id,@RequestParam("file_type") String file_type) throws Exception
    {
        if(!StringUtils.isEmpty(relation_id)){
            if (!file.isEmpty())
            {
                QuotFile quotFile= new QuotFile();
                quotFile.setFileId(UUID.fastUUID().toString());

                String url = FileUploadUtils.uploadMinio(file,"quot-manage",  "quot/"+relation_id);
                int index = url.lastIndexOf("/")+1;
                String fileName = url.substring(index);

                int index2 = url.indexOf("/quot/");
                String fileBucketName = url.substring(index2);

                quotFile.setFileName(fileName);
                quotFile.setFileBucketName(fileBucketName);
                quotFile.setFileUrl(url);
                quotFile.setFileSize(file.getSize());
                quotFile.setFileTime(DateUtils.getTime());
                quotFile.setFileType(file_type);
                quotFile.setRelationId(relation_id);
                quotFileService.insertQuotFile(quotFile);
            }
        }else{
            return error("系统异常,报价单号为空!");
        }
        return success("上传成功!");
    }

    /**
     * 查询附件列表
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:list')")
    @GetMapping("/quotFileList")
    public TableDataInfo quotFileList(QuotFile quotFile)
    {
        startPage();
        List<QuotFile> list = quotFileService.selectQuotFileList(quotFile);
        return getDataTable(list);
    }

    /**
     * 删除附件列表
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:list')")
    @PostMapping("/quotFileDelete")
    public AjaxResult quotFileDelete(QuotFile quotFile) {
        String fileId = quotFile.getFileId();
        try {
            QuotFile quotfile = quotFileService.selectQuotFileByFileId(fileId);
            quotFileService.deleteQuotFileByFileId(fileId);
            MinioUtil.removeObject("quot-manage", quotfile.getFileBucketName());
        }catch(Exception e){
            return error("系统异常!");
        }
        return success();
    }

    /**
     * 提交报价单
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:commit')")
    @Log(title = "报价单提交", businessType = BusinessType.OTHER)
    @PostMapping("/commitQuot")
    public AjaxResult commitQuot(@RequestBody Quot quot)
    {
        String quot_id = quot.getQuotId();
        if(StringUtils.isEmpty(quot_id)){
            quot.setQuotId(UUID.fastUUID().toString());
            quot.setQuotCode(IdUtils.createNo("BJD_",2));
            quot.setCreateBy(getUsername());
            quot.setQuotApprovalStatus("1");//提交报价组
            quotService.insertQuot(quot);
            return success();
        }else{
            quot.setUpdateBy(getUsername());
            quot.setQuotApprovalStatus("1");//提交报价组
            quotService.updateQuot(quot);
            return success();
        }
    }

    /**
     * 报价单提交技术协助
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:assist')")
    @Log(title = "报价单提交技术协助", businessType = BusinessType.OTHER)
    @PostMapping("/commitJsQuot")
    public AjaxResult commitJsQuot(@RequestBody Quot quot)
    {
        String quotJsxzGroup = quot.getQuotJsxzGroup();
        if(StringUtils.isEmpty(quotJsxzGroup)){
            return error("请先选择分组");
        }else{

        }

        return success();
    }
}
